@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.11
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
@@ -11,7 +11,7 @@ Python 3 library for [rlwrap](https://github.com/hanslub42/rlwrap) filters
     filter.output_handler = lambda x: re.sub('apple', 'orange', x) # re−write output
     filter.prompt_handler = munge_prompt
     filter.completion_handler = complete_handler
-    filter.history_handler = lambda x: re.sub(r'(identified\s+by\s+)(\S+)', r'\\1xXxXxXxX', x)
+    filter.history_handler = lambda x: re.sub(r'(identified\\s+by\\s+)(\\S+)', r'\\1xXxXxXxX', x)
     filter.run()
 
 This is an [RlwrapFilter](https://github.com/hanslub42/rlwrap/wiki/RlwrapFilter.pm-manpage)
@@ -33,6 +33,8 @@ rlwrapfilter.py makes it very simple to write rlwrap
 filters in Python 3. A filter only needs to instantiate a RlwrapFilter
 object, change a few of its default handlers and then call its 'run'
 method.
+
+This module and numerous python filters were contributed by Hisanobu Okuda.
 """
 
 
@@ -208,12 +210,15 @@ def read_from_stdin():
     tagname = None
     while (tag is None):
         try:
-            m = re.match("(\S+) (.*?)\r?\n", sys.stdin.readline())
+            m = re.match(r'(\S+) (.*?)\r?\n', sys.stdin.readline())
         except KeyboardInterrupt:
             sys.exit()
         if not m:
             sys.exit()
         tagname, message = m.groups()
+        tagname=tagname.upper()            # allow lowercase tag names
+        if not re.match(r'TAG_', tagname): # allow omitting the tiresome "TAG_" prefix
+            tagname = "TAG_" + tagname
         message.replace("\\t","\t").replace("\\n","\n")
         tag = name2tag(tagname)
     return tag, message
@@ -493,8 +498,8 @@ class RlwrapFilter:
         response = read_until(CMD_OUT, prompt, timeout,
                               prompt_search_from=prompt_search_from,
                               prompt_search_to=prompt_search_to)
-        response = re.sub('^.*?\n', '', response) # chop off echoed question;
-        response = re.sub('{0}$'.format(prompt), '', response) # chop off prompt;
+        response = re.sub(r'^.*?\n', '', response) # chop off echoed question;
+        response = re.sub(r'{0}$'.format(prompt), '', response) # chop off prompt;
         if (self.cloak_and_dagger_verbose):
             self.send_output_oob("cloak_and_dagger response: {0}\n".format(response))
         return response
@@ -625,14 +630,14 @@ class RlwrapFilter:
                     write_message(tag,REJECT_PROMPT);
                     # don't update <previous_tag> and don't reset <cumulative_input>
                     next
-                if (os.environ.get('RLWRAP_IMPATIENT') and not re.search('\n$', self.cumulative_output)):
+                if (os.environ.get('RLWRAP_IMPATIENT') and not re.search(r'\n$', self.cumulative_output)):
                     # cumulative output contains prompt: chop it off!
                     # s/[^\n]*$// takes way too long on big strings,
                     # what is the optimal regex to do this?
-                    self.cumulative_output = re.sub('(?<![^\n])[^\n]*$', '', self.cumulative_output)
+                    self.cumulative_output = re.sub(r'(?<![^\n])[^\n]*$', '', self.cumulative_output)
 
                 response = when_defined(self.prompt_handler, message)
-                if (re.search('\n', response)):
+                if (re.search(r'\n', response)):
                     send_error('prompts may not contain newlines!')
             elif (tag == TAG_SIGNAL):
                 response = when_defined(self.signal_handler, message)
